#!/bin/bash
#
# build-client.sh
#
# Copyright (C) 2011-2012 Cesnet z.s.p.o
# Author(s):    Tomas PLESNIK   <plesnik@ics.muni.cz>
#               Jan SOUKAL      <soukal@ics.muni.cz>
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the Cesnet z.s.p.o nor the names of its
#    contributors may be used to endorse or promote products derived from
#     this software without specific prior written permission.
#
# This software is provided ``as is'', and any express or implied
# warranties, including, but not limited to, the implied warranties of
# merchantability and fitness for a particular purpose are disclaimed.
# In no event shall the Cesnet z.s.p.o or contributors be liable for
# any direct, indirect, incidental, special, exemplary, or consequential
# damages (including, but not limited to, procurement of substitute
# goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether
# in contract, strict liability, or tort (including negligence or
# otherwise) arising in any way out of the use of this software, even
# if advised of the possibility of such damage.

VERSION="1.1.0"

err()
{
  echo "FAILED!"
  cat $err
  rm -rf $err $package $tar $sig
  echo
  echo "Build of $package package FAILED!!!"
  exit 1
}


#-------------------------------------------------------------------------------
#				MAIN
#-------------------------------------------------------------------------------

# edit when you build new package
version="1.1.0"

package_name="warden-client"
package="$package_name-$version"
doc="$package/$package_name/doc"
etc="$package/$package_name/etc"
lib="$package/$package_name/lib"
var="$package/$package_name/var"
tar="$package.tar.gz"
sig="$tar.sig"
err="/tmp/$package-err"

# make directory structure
echo "Building $package_name package version $version ..."
echo

echo -n "Building 'base' directory ... "
mkdir -p $package 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
cp -R ../src/$package_name/sh/* $package 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
cp ../src/$package_name/doc/CHANGELOG $package 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
cp ../src/$package_name/doc/INSTALL $package 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
cp ../src/$package_name/doc/LICENSE $package 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
cp ../src/$package_name/doc/README $package 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
cp ../src/$package_name/doc/README.cesnet $package 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi

echo "OK"


echo -n "Building '$doc' directory ... "
mkdir -p $doc 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
cp -R ../src/$package_name/doc/* $doc 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
echo "OK"


echo -n "Building '$etc' directory ... "
mkdir -p $etc 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
cp ../src/$package_name/etc/package_version $etc 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
echo "OK"


echo -n "Building '$lib' directory ... "
mkdir -p $lib 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
cp -R ../src/$package_name/lib/* $lib 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
echo "OK"


echo -n "Building '$var' directory ... "
mkdir -p $var 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
echo "OK"


# create tarball
echo -n "Creating $tar tarball ... "
tar czf $tar $package 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
echo "OK"


# create sign of tarball
echo -n "Creating $sig file ... "
sha1sum $tar > $sig 2> $err; ret_val=`echo $?`
if [ $ret_val -ne 0 ]; then
  err
fi
echo "OK"


echo
echo "Building of $package package was SUCCESSFULL"

# cleanup section
rm -rf $package $err

exit 0
